@@ -1,13 +1,16 @@
 /* delete.c - shell backend delete function */
 
+#include "portable.h"
+
 #include <stdio.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/socket.h>
+
+#include <ac/string.h>
+#include <ac/socket.h>
+
 #include "slap.h"
 #include "shell.h"
 
-void
+int
 shell_back_delete(
     Backend	*be,
     Connection	*conn,
@@ -21,19 +24,19 @@ shell_back_delete(
 	if ( si->si_delete == NULL ) {
 		send_ldap_result( conn, op, LDAP_UNWILLING_TO_PERFORM, NULL,
 		    "delete not implemented" );
-		return;
+		return( -1 );
 	}
 
 	if ( (op->o_private = forkandexec( si->si_delete, &rfp, &wfp ))
 	    == -1 ) {
 		send_ldap_result( conn, op, LDAP_OPERATIONS_ERROR, NULL,
 		    "could not fork/exec" );
-		return;
+		return( -1 );
 	}
 
 	/* write out the request to the delete process */
 	fprintf( wfp, "DELETE\n" );
-	fprintf( wfp, "msgid: %d\n", op->o_msgid );
+	fprintf( wfp, "msgid: %ld\n", op->o_msgid );
 	print_suffixes( wfp, be );
 	fprintf( wfp, "dn: %s\n", dn );
 	fclose( wfp );
@@ -41,4 +44,5 @@ shell_back_delete(
 	/* read in the results and send them along */
 	read_and_send_results( be, conn, op, rfp, NULL, 0 );
 	fclose( rfp );
+	return( 0 );
 }
