@@ -474,6 +474,8 @@ generate_new_centroids(
 	char		**val;
 	char		last;
 
+	memset( &data, 0 , sizeof( data ));
+
 	if ( verbose ) {
 		printf( "Generating new centroids for..." );
 		fflush( stdout );
@@ -496,6 +498,9 @@ generate_new_centroids(
 
 			/* for each value */
 			for ( j = 0; val[j] != NULL; j++ ) {
+
+				memset( &key, 0 , sizeof( key ));
+
 				/* normalize the value */
 				for ( s = val[j]; *s; s++ ) {
 					if ( isascii( *s ) ) {
@@ -571,6 +576,14 @@ diff_centroids(
 		fflush( stdout );
 	}
 
+	memset( &okey, 0, sizeof( okey ));
+	memset( &nkey, 0, sizeof( nkey ));
+	memset( &olast, 0, sizeof( olast ));
+	memset( &nlast, 0, sizeof( nlast ));
+	memset( &lastkey, 0, sizeof( lastkey ));
+	memset( &key, 0, sizeof( key ));
+	memset( &data, 0, sizeof( data ));
+
 	if ( (mods = (LDAPMod **) malloc( sizeof(LDAPMod *) * 4 )) == NULL ||
 	     (mods[0] = (LDAPMod *) malloc( sizeof(LDAPMod) )) == NULL ||
 	     (mods[1] = (LDAPMod *) malloc( sizeof(LDAPMod) )) == NULL ||
@@ -833,6 +846,9 @@ full_centroid(
 		fflush( stdout );
 	}
 
+	memset( &key, 0, sizeof( key ));
+	memset( &lastkey, 0, sizeof( lastkey ));
+
 	if ( (mods = (LDAPMod **) malloc( sizeof(LDAPMod *) * 3 )) == NULL ||
 	     (mods[0] = (LDAPMod *) malloc( sizeof(LDAPMod) )) == NULL ||
 	     (mods[1] = (LDAPMod *) malloc( sizeof(LDAPMod) )) == NULL ||
