@@ -61,6 +61,7 @@ main( int argc, char **argv )
 	ID		id;
 	struct dbcache	*db, *db2;
 	Backend		*be = NULL;
+	struct ldbminfo *li;
 	struct berval	bv;
 	struct berval	*vals[2];
 	Avlnode		*avltypes = NULL;
@@ -127,6 +128,10 @@ main( int argc, char **argv )
 	}
 	be = &backends[dbnum];
 
+	/* disable write sync'ing */
+	li = (struct ldbminfo *) be->be_private;
+	li->li_dbcachewsync = 0;
+
 	/*
 	 * first, make the dn2id index
 	 */
@@ -149,6 +154,9 @@ main( int argc, char **argv )
 		int		vlen;
 		Datum		key, data;
 
+		memset( &key, 0, sizeof( key ));
+		memset( &data, 0, sizeof( data ));
+
 		if ( fgets( line, sizeof(line), stdin ) != NULL ) {
 			int     len;
 
@@ -232,6 +240,9 @@ main( int argc, char **argv )
 		char	buf2[20];
 		Datum	key, data;
 
+		memset( &key, 0, sizeof( key ));
+		memset( &data, 0, sizeof( data ));
+
 		if ( fgets( line, sizeof(line), stdin ) != NULL ) {
 			int     len;
 
